class Regexp
    def uses_bos
        source[ 0 ] == ?^
    end
end

